@@ -15,9 +15,9 @@
 #include "ComicMainWindow.h"
 #include "Page.h"
 #include "ComicBookInfo.h"
-#include "ContinuousPageView.h"
-#include "SimplePageView.h"
-#include "FrameView.h"
+#include "View/ContinuousPageView.h"
+#include "View/SimplePageView.h"
+#include "View/FrameView.h"
 #include "Archivers/ArchiversConfiguration.h"
 #include "Sink/ImgDirSink.h"
 #include "Sink/ImgSinkFactory.h"
@@ -39,6 +39,7 @@
 #include "PrinterThread.h"
 #include <FrameDetectThread.h>
 #include "PrintProgressDialog.h"
+#include "Job/ImageTransformThread.h"
 #include <QMenu>
 #include <QStringList>
 #include <QAction>
@@ -54,7 +55,7 @@
 #include <QPrinter>
 #include <QPrintDialog>
 #include <QApplication>
-#include <QDebug>
+#include "ComicBookDebug.h"
 
 using namespace QComicBook;
 using namespace Utility;
@@ -136,6 +137,21 @@ ComicMainWindow::ComicMainWindow(QWidget *parent): QMainWindow(parent), currpage
     actionToggleStatusbar->setChecked(cfg->showStatusbar());
     statusbar->setShown(cfg->showStatusbar());
 
+    //
+    // Lens zoom levels
+    zoomgrp = new QActionGroup(this);
+    action200->setChecked(true);
+    action200->setData(2.0f);
+    action300->setData(3.0f);
+    action400->setData(4.0f);
+    action800->setData(8.0f);
+    zoomgrp->setExclusive(true);
+    zoomgrp->addAction(action200);
+    zoomgrp->addAction(action300);
+    zoomgrp->addAction(action400);
+    zoomgrp->addAction(action800);
+    connect(zoomgrp, SIGNAL(triggered(QAction *)), this, SLOT(setLensZoom(QAction *)));
+
     setupComicImageView();
 
     //
@@ -239,6 +255,8 @@ ComicMainWindow::ComicMainWindow(QWidget *parent): QMainWindow(parent), currpage
 
 ComicMainWindow::~ComicMainWindow()
 {
+    ImageTransformThread::get()->stop();
+
     if (cfg->cacheThumbnails())
     {
         ImgDirSink::removeThumbnails(cfg->thumbnailsAge());
@@ -294,9 +312,11 @@ void ComicMainWindow::setupContextMenu()
 
 void ComicMainWindow::setupComicImageView()
 {
+    _DEBUG;
     const int n = (sink != NULL ? sink->numOfImages() : 0);
     if (view)
     {
+        _DEBUG << "disconnecting old view";
         view->disconnect();
         pageLoader->disconnect();
         view->deleteLater();
@@ -352,6 +372,7 @@ void ComicMainWindow::setupComicImageView()
     connect(actionNoRotation, SIGNAL(triggered(bool)), view, SLOT(resetRotation()));
     connect(actionJumpDown, SIGNAL(triggered()), view, SLOT(jumpDown()));
     connect(actionJumpUp, SIGNAL(triggered()), view, SLOT(jumpUp()));
+    connect(actionLens, SIGNAL(triggered(bool)), this, SLOT(showLens(bool)));
     
     connect(view, SIGNAL(bottomReached()), this, SLOT(nextPage()));
     connect(view, SIGNAL(topReached()), this, SLOT(prevPageBottom()));
@@ -375,6 +396,8 @@ void ComicMainWindow::setupComicImageView()
     {
          jumpToPage(currpage, true);
     }
+
+    showLens(actionLens->isChecked());
 }
 
 void ComicMainWindow::applyFullscreenSettings()
@@ -409,6 +432,15 @@ void ComicMainWindow::enableComicBookActions(bool f)
         actionRotateRight->setEnabled(f);
         actionRotateLeft->setEnabled(f);
         actionNoRotation->setEnabled(f);
+        actionLens->setEnabled(f);
+
+        //
+        // lens
+        zoomgrp->setEnabled(f);
+        action200->setEnabled(f);
+        action300->setEnabled(f);
+        action400->setEnabled(f);
+        action800->setEnabled(f);
 
         //
         // navigation menu
@@ -532,6 +564,23 @@ void ComicMainWindow::setPageSize(QAction *action)
     view->setSize(size);
 }
 
+void ComicMainWindow::setLensZoom(QAction *action)
+{
+	if (view)
+	{
+		view->setLensZoom(action->data().toDouble());
+	}	
+}
+
+void ComicMainWindow::showLens(bool f)
+{
+	QAction *lzoom = zoomgrp->checkedAction();
+	if (view && lzoom)
+	{
+		view->showLens(f, lzoom->data().toDouble());
+	}
+}
+
 void ComicMainWindow::reloadPage()
 {
     if (sink)
@@ -562,7 +611,7 @@ void ComicMainWindow::recentSelected(const QString &fname)
 
 void ComicMainWindow::pageLoaded(const Page &page)
 {
-    qDebug() << "page ready " << page.getNumber();
+    _DEBUG << page.getNumber();
     if (currpage == page.getNumber())
     {
         statusbar->setImageInfo(&page);
@@ -571,7 +620,7 @@ void ComicMainWindow::pageLoaded(const Page &page)
 
 void ComicMainWindow::pageLoaded(const Page &page1, const Page &page2)
 {
-    qDebug() << "page ready " << page1.getNumber() << ", " << page2.getNumber();
+    _DEBUG << page1.getNumber() << ", " << page2.getNumber();
     if (currpage == page1.getNumber() || currpage == page2.getNumber())
     {
         statusbar->setImageInfo(&page1, &page2);
@@ -580,6 +629,7 @@ void ComicMainWindow::pageLoaded(const Page &page1, const Page &page2)
 
 void ComicMainWindow::sinkReady(const QString &path)
 {
+    _DEBUG;
 	statusbar->setShown(actionToggleStatusbar->isChecked() && !(isFullScreen() && cfg->fullScreenHideStatusbar())); //applies back user's statusbar&toolbar preferences
 	//toolbar->setShown(actiontoggleToolbar->isOn() && !(isFullScreen() && cfg->fullScreenHideToolbar()));
 
@@ -726,6 +776,7 @@ void ComicMainWindow::exitFullscreen()
 
 void ComicMainWindow::nextPage()
 {
+    _DEBUG;
     const int n(view->nextPage(currpage));
     if (n >= 0)
     {
@@ -735,6 +786,7 @@ void ComicMainWindow::nextPage()
 
 void ComicMainWindow::prevPage()
 {
+    _DEBUG;
     const int n(view->previousPage(currpage));
     if (n >= 0)
     {
@@ -744,11 +796,13 @@ void ComicMainWindow::prevPage()
 
 void ComicMainWindow::prevFrame()
 {
+    _DEBUG;
     view->prevFrame();
 }
 
 void ComicMainWindow::nextFrame()
 {
+    _DEBUG;
     view->nextFrame();
 }
 
@@ -786,6 +840,7 @@ void ComicMainWindow::backwardPages()
 
 void ComicMainWindow::jumpToPage(int n, bool force)
 {
+    _DEBUG;
 	if (!sink)
         {
 		return;
@@ -811,6 +866,8 @@ void ComicMainWindow::jumpToPage(int n, bool force)
 
 void ComicMainWindow::currentPageChanged(int n)
 {
+    _DEBUG << n;
+
     currpage = n;
     const QString page = tr("Page") + " " + QString::number(n + 1) + "/" + QString::number(sink->numOfImages());
     pageinfo->setText(page);
@@ -863,7 +920,7 @@ void ComicMainWindow::showAbout()
                         "QComicBook " VERSION " - comic book viewer for GNU/Linux<br>"
                         "(c)by Pawel Stolowski 2005-2010<br>"
                         "released under terms of GNU General Public License<br><br>"
-                        "<a href=\"http://qcomicbook.linux-projects.net\">http://qcomicbook.linux-projects.net</a><br>"
+                        "<a href=\"http://www.qcomicbook.org\">http://www.qcomicbook.org</a><br>"
                         "<a href=\"mailto:stolowski@gmail.com\">stolowski@gmail.com</a>", QPixmap(":/images/qcomicbook-splash.png"));
         win->show();
 }
@@ -915,6 +972,8 @@ void ComicMainWindow::showAboutQt()
 
 void ComicMainWindow::closeSink()
 {
+    _DEBUG;
+
     enableComicBookActions(false);
 
     if (sink)
@@ -934,12 +993,15 @@ void ComicMainWindow::closeSink()
 
 void ComicMainWindow::setBookmark()
 {
+    _DEBUG;
+
         if (sink)
                 bookmarks->set(sink->getFullName(), currpage);
 }
 
 void ComicMainWindow::removeBookmark()
 {
+    _DEBUG;
         if (sink && bookmarks->exists(sink->getFullName()) && QMessageBox::question(this, tr("Removing bookmark"),
                                 tr("Do you really want to remove bookmark\nfor this comic book?"),
                                 QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)
@@ -1000,6 +1062,8 @@ void ComicMainWindow::openPrintDialog()
 
 void ComicMainWindow::bookmarkSelected(QAction *action) 
 {
+    _DEBUG;
+
         Bookmark b;
         if (bookmarks->get(action, b))
         {
@@ -1028,6 +1092,8 @@ void ComicMainWindow::bookmarkSelected(QAction *action)
 			
 void ComicMainWindow::changeViewType(QAction *action)
 {
+    _DEBUG;
+
     if (action == actionContinuousView)
     {
 	cfg->viewType(Continuous);
@@ -1045,6 +1111,8 @@ void ComicMainWindow::changeViewType(QAction *action)
 
 void ComicMainWindow::saveSettings()
 {
+    _DEBUG;
+
         cfg->saveGeometry(this);
         cfg->saveDockLayout(this);
         cfg->lastDir(lastdir);
@@ -1057,6 +1125,8 @@ void ComicMainWindow::saveSettings()
 
 void ComicMainWindow::reconfigureDisplay()
 {
+    _DEBUG;
+
     view->setSmallCursor(cfg->smallCursor());
     view->showPageNumbers(cfg->embedPageNumbers());
     view->setBackground(cfg->background());
@@ -1064,5 +1134,7 @@ void ComicMainWindow::reconfigureDisplay()
 
 void ComicMainWindow::printingFinished()
 {
+    _DEBUG;
+
     printThread->deleteLater();
 }
