@@ -11,17 +11,21 @@
  */
 
 #include "FrameWidget.h"
-#include "FrameView.h"
+#include "View/FrameView.h"
 #include <ComicFrame.h>
 #include "Page.h"
 #include <QPainter>
 #include <QImage>
+#include "ComicBookDebug.h"
+#include "Job/FrameRedrawJob.h"
+#include "Job/ImageJobResult.h"
+#include "Job/JobType.h"
 
 using namespace QComicBook;
 
 FrameWidget::FrameWidget(FrameView *parent, int w, int h)
-	: ComicImageWidget(parent, w, h)
-	  , m_image(0)
+	: ComicImageWidget(parent)
+        , m_image(0), m_framekey(-1)
 {
 }
 
@@ -32,19 +36,40 @@ FrameWidget::~FrameWidget()
 
 void FrameWidget::setFrame(const Page &p, const ComicFrame &f)
 {
+    _DEBUG;
 	m_image = new QImage(p.getImage());
 	m_frame = QRect(f.xPos(), f.yPos(), f.width(), f.height());
+        m_framekey = ((f.xPos() & 0xffff) << 16) | (f.yPos() & 0xffff);
 
 	setSourceSize(f.width(), f.height());
 	redrawScaledImage();
 }
 
-void FrameWidget::redraw(QPainter &p)
+ImageTransformJob* FrameWidget::redrawJob()
 {
-	if (m_image)
-	{
-		p.drawImage(0, 0, *m_image, m_frame.x(), m_frame.y(), m_frame.width(), m_frame.height());
-	}
+    _DEBUG;
+    FrameRedrawJob *j = NULL;
+    if (m_image)
+    {
+        j = new FrameRedrawJob();
+        j->setKey(JobKey(FRAME_REDRAW, m_framekey));
+        j->setImage(*m_image, m_frame);
+    }
+    return j;
+}
+
+bool FrameWidget::jobCompleted(const ImageJobResult &result)
+{
+    _DEBUG << result.key;
+    if (m_image && result.key.getKey() == m_framekey)
+    {
+        _DEBUG << "matching job" << result.key;
+        if (ComicImageWidget::jobCompleted(result))
+        {
+            return true;
+        }
+    }
+    return false;
 }
 
 void FrameWidget::clear()
@@ -53,3 +78,8 @@ void FrameWidget::clear()
 	m_image = 0;
 	dispose();
 }
+			
+void FrameWidget::propsChanged()
+{
+    _DEBUG;
+}
